@@ -144,8 +144,8 @@ c-----------------------------------------------------------------------
 
       integer info
 
-      double precision Rzero, Rone
-      parameter(Rzero=0.0d0, Rone=1.0d0)
+      double precision Rone
+      parameter(Rone=1.0d0)
 
 c     perform a QR factorization of rjac (simple Lapack routine)
 c     check for singularity or ill conditioning
